deprecated_helper
=================

This helper is deprecated since v0.1.0.  Use :func:`stable_function`
instead.

.. py:function:: deprecated_helper(value)

   .. badges:: stability:deprecated area:utils

   .. deprecated:: 0.1.0

      Use :func:`stable_function`.

   :param value: The value to process.
